<?php

/**
 * Plugin Name: Settings Parameters
 * Description: Allows use of global parameters
 * Version: 0.1.0
 * Author: Infomaker Scandinavia AB
 * Author URI: https://infomaker.se
 */

use Infomaker\Everyware\Support\Environment;
use Everyware\Plugin\SettingsParameters\PluginSettingsForm;
use Everyware\Plugin\SettingsParameters\PluginSettingsParameters;
use Everyware\ProjectPlugin\Components\Adapters\PluginSettingsTabAdapter;
use Everyware\ProjectPlugin\Components\SettingsHandler;
use Everyware\ProjectPlugin\Helpers\FileReader; 
use Everyware\ProjectPlugin\Components\ComponentAdmin;
use Everyware\ProjectPlugin\ProjectPlugin;
use Infomaker\Everyware\Support\Str;
use Infomaker\Everyware\Twig\ViewSetup;

if ( ! defined('WPINC') || ! class_exists(ProjectPlugin::class)) {
    exit;
}

add_action('admin_enqueue_scripts', function () {
    if (is_admin()) {
        $assetsPath = plugin_dir_url(__FILE__) . 'assets';
        $scriptVersion = Environment::isDev() ? false : GIT_COMMIT;
        wp_enqueue_script(
            'everyware-settings-parameters',"{$assetsPath}/js/ajax.js", ['jquery'], $scriptVersion, true
        );
        wp_localize_script( 'everyware-settings-parameters', 'settings_parameters_ajax', array( 'ajax_url' => admin_url('admin-ajax.php')) );
    }
});

ViewSetup::getInstance()->registerTwigFolder('plugins', __DIR__ . '/src/templates/');

if (is_admin()) {
    $fileReader = new FileReader(__FILE__);

    $pluginName = $fileReader->getHeader('Plugin Name');
    $settingsHandler = new SettingsHandler(Str::slug('everyware-' . $pluginName));

    $pluginSettingsTab = new ComponentAdmin(
        new PluginSettingsForm($fileReader, $settingsHandler),
        new PluginSettingsParameters()
    );

    ProjectPlugin::getInstance()->addSettingsTab(new PluginSettingsTabAdapter($pluginSettingsTab));
}
