<?php declare(strict_types=1);

namespace Everyware\Plugin\SettingsParameters;

use Everyware\ProjectPlugin\Components\ComponentSettingsForm;
use Infomaker\Everyware\Twig\View;
use Everyware\ProjectPlugin\Helpers\JsonImporter;

/**
 * Class SettingsForm
 * @package Everyware\Plugin\GoogleAnalytics
 */
class PluginSettingsForm extends ComponentSettingsForm
{
    private const SUBMIT_KEY = 'everyware-settings-parameters-submit';

    protected $textDomain = 'everyware_project_plugin_text_domain';
    private $collection;

    public function generateView($parameters, $collection)
    {
        $this->collection = $collection;
        return View::generate('@plugins/body', [
            'body' => $this->pageContent($parameters),
        ]);
    }
    /**
     * @param string $import
     * @param string $export
     *
     * @return string
     */
    private function generateJsonImporter(array $export): string
    {
        return View::generate('@plugins/import-export', [
            'field_name' => JsonImporter::POST_KEY,
            'import' => '',
            'export' => $export ? json_encode(array_map(function ($parameter) {
                return [
                    'key' => $parameter['key']['value'], 'value' => $parameter['value']['value']
                ];
            }, $export))
            : '',
            'import_form_action' => $_SERVER['REQUEST_URI'],
        ]);
    }

    public function pageContent($parameters): string
    {
        return View::generate('@plugins/settings-parameters', [
            'form_action' => $_SERVER['REQUEST_URI'],
            'submit_key' => static::SUBMIT_KEY,
            'text_domain' => $this->textDomain,
            'template' => [
                'key' => '', 'value' => '', 'label_key' => 'Key', 'label_value' => 'Value'
            ],
            'parameters' => $parameters ? array_map(function ($parameter) {
                return [
                    'key' => $parameter['key']['value'], 'id' => $parameter['key']['id'], 'value' => $parameter['value']['value'], 'label_key' => 'Key', 'label_value' => 'Value'
                ];
            }, $parameters) 
            : '',
            'json_import' => $this->generateJsonImporter($parameters)
                
        ]);
    }

    protected function formContent($storedData): string
    {
        $viewData = $this->settingsHandler->generateFormData($storedData);
       /*  print_r('<pre>');
        print_r($viewData);
        print_r('</pre>');
        die(); */
        $parameters = $viewData['parameters'] ?? [];

        return View::generate('@plugins/body', [
            'body' => $this->pageContent($parameters),
        ]);
    }
}